# Setup

Please insert a `__init__.py` file in the configuration folder with the following line of code: `PATH_TO_PROJECT = '/home/YOUR_NAME_HERE/code/YOUR_NAME_HERE/fsbc_master_thesis_jan_spoerer_crypto_trading_strategy'`

# Background

This project is the main part of a Master's thesis by Jan Spörer at the Frankfurt School Blockchain Center. It has just been started, but you can track the thesis's progress here: https://www.overleaf.com/read/mtfktgqqwvsr